import { T as ThemeInput, L as LanguageInput, b as CodeToThemedTokensOptions, c as ThemedToken, C as CodeToHtmlOptions, d as CodeToHtmlDualThemesOptions } from './types/types.mjs';
export { A as Awaitable, a as BuiltinLanguages, B as BuiltinThemes, E as ElementsOptions, H as HtmlRendererOptions, g as LanguageRegistration, h as LineOption, f as MaybeArray, M as MaybeGetter, e as MaybeModule, P as PlainTextLanguage, R as RequireKeys, S as StringLiteralUnion, j as ThemeRegisteration, i as ThemeRegisterationRaw, l as ThemedTokenExplanation, k as ThemedTokenScopeExplanation } from './types/types.mjs';

interface WebAssemblyInstantiator {
    (importObject: Record<string, Record<string, WebAssembly.ImportValue>> | undefined): Promise<WebAssembly.WebAssemblyInstantiatedSource | WebAssembly.Instance>;
}
interface ICommonOptions {
    print?(str: string): void;
}
interface IInstantiatorOptions extends ICommonOptions {
    instantiator: WebAssemblyInstantiator;
}
interface IDataOptions extends ICommonOptions {
    data: ArrayBufferView | ArrayBuffer | Response;
}
type OnigurumaLoadOptions = IInstantiatorOptions | IDataOptions;
declare function loadWasm(loader: WebAssemblyInstantiator): Promise<void>;
declare function loadWasm(options: OnigurumaLoadOptions): Promise<void>;
declare function loadWasm(data: ArrayBufferView | ArrayBuffer | Response): Promise<void>;

interface HighlighterCoreOptions {
    themes: ThemeInput[];
    langs: LanguageInput[];
    loadWasm?: OnigurumaLoadOptions | (() => Promise<OnigurumaLoadOptions>);
}
type HighlighterCore = Awaited<ReturnType<typeof getHighlighterCore>>;

declare function getHighlighterCore(options: HighlighterCoreOptions): Promise<{
    codeToThemedTokens: (code: string, options?: CodeToThemedTokensOptions) => ThemedToken[][];
    codeToHtml: (code: string, options?: CodeToHtmlOptions) => string;
    codeToHtmlDualThemes: (code: string, options: CodeToHtmlDualThemesOptions) => string;
    loadLanguage: (...langs: LanguageInput[]) => Promise<void>;
    loadTheme: (...themes: ThemeInput[]) => Promise<void>;
    getLoadedThemes: () => string[];
    getLoadedLanguages: () => string[];
}>;

export { CodeToHtmlDualThemesOptions, CodeToHtmlOptions, CodeToThemedTokensOptions, HighlighterCore, HighlighterCoreOptions, LanguageInput, ThemeInput, ThemedToken, getHighlighterCore, loadWasm };
