import { T as ThemeInput, B as BuiltinThemes, L as LanguageInput, a as BuiltinLanguages, P as PlainTextLanguage, C as CodeToHtmlOptions, b as CodeToThemedTokensOptions, c as ThemedToken, d as CodeToHtmlDualThemesOptions, R as RequireKeys } from './types/types.mjs';
export { A as Awaitable, E as ElementsOptions, H as HtmlRendererOptions, g as LanguageRegistration, h as LineOption, f as MaybeArray, M as MaybeGetter, e as MaybeModule, S as StringLiteralUnion, j as ThemeRegisteration, i as ThemeRegisterationRaw, l as ThemedTokenExplanation, k as ThemedTokenScopeExplanation, p as bundledLanguages, o as bundledLanguagesAlias, n as bundledLanguagesBase, m as bundledThemes } from './types/types.mjs';
export { HighlighterCore, HighlighterCoreOptions, getHighlighterCore, loadWasm } from './core.mjs';
export { getWasmInlined } from './wasm.mjs';

interface HighlighterOptions {
    themes?: (ThemeInput | BuiltinThemes)[];
    langs?: (LanguageInput | BuiltinLanguages | PlainTextLanguage)[];
}
type Highlighter = Awaited<ReturnType<typeof getHighlighter>>;
declare function getHighlighter(options?: HighlighterOptions): Promise<{
    codeToHtml(code: string, options?: CodeToHtmlOptions<BuiltinLanguages, BuiltinThemes>): string;
    loadLanguage(...langs: (LanguageInput | BuiltinLanguages | PlainTextLanguage)[]): Promise<void>;
    loadTheme(...themes: (ThemeInput | BuiltinThemes)[]): Promise<void>;
    codeToThemedTokens: (code: string, options?: CodeToThemedTokensOptions<string, string>) => ThemedToken[][];
    codeToHtmlDualThemes: (code: string, options: CodeToHtmlDualThemesOptions<string, string>) => string;
    getLoadedThemes: () => string[];
    getLoadedLanguages: () => string[];
}>;

/**
 * Shorthand for `codeToHtml` with auto-loaded theme and language.
 * A singleton highlighter it maintained internally.
 *
 * Differences from `shiki.codeToHtml()`, this function is async.
 */
declare function codeToHtml(code: string, options: RequireKeys<CodeToHtmlOptions<BuiltinLanguages, BuiltinThemes>, 'theme' | 'lang'>): Promise<string>;
/**
 * Shorthand for `codeToThemedTokens` with auto-loaded theme and language.
 * A singleton highlighter it maintained internally.
 *
 * Differences from `shiki.codeToThemedTokens()`, this function is async.
 */
declare function codeToThemedTokens(code: string, options: RequireKeys<CodeToThemedTokensOptions<BuiltinLanguages, BuiltinThemes>, 'theme' | 'lang'>): Promise<ThemedToken[][]>;
/**
 * Shorthand for `codeToHtmlDualThemes` with auto-loaded theme and language.
 * A singleton highlighter it maintained internally.
 *
 * Differences from `shiki.codeToHtmlDualThemes()`, this function is async.
 */
declare function codeToHtmlDualThemes(code: string, options: RequireKeys<CodeToHtmlDualThemesOptions<BuiltinLanguages, BuiltinThemes>, 'theme' | 'lang'>): Promise<string>;

export { BuiltinLanguages, BuiltinThemes, CodeToHtmlDualThemesOptions, CodeToHtmlOptions, CodeToThemedTokensOptions, Highlighter, HighlighterOptions, LanguageInput, PlainTextLanguage, RequireKeys, ThemeInput, ThemedToken, codeToHtml, codeToHtmlDualThemes, codeToThemedTokens, getHighlighter };
